@@ -11,84 +11,90 @@ use derive_more::{Display, From, Into};
 use deunicode::deunicode;
 use fnv::{FnvHashMap, FnvHashSet};
 use std::collections::HashMap;
-use std::fmt;
 use std::io::{BufRead, Write};
 use std::ops::Index;
 
-/// Specifies if a query is for movies or series database
-#[derive(Clone, Copy)]
+/// Specifies the type of title a query is for. E.g. Movies or Series.
+#[derive(Clone, Copy, Display)]
+#[display(fmt = "{}")]
 pub enum Query {
-  /// Movies
+  /// Query the database of Movies.
+  #[display(fmt = "movie")]
   Movies,
-  /// Series
+
+  /// Query the database of Series.
+  #[display(fmt = "series")]
   Series,
 }
 
-impl fmt::Display for Query {
-  fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-    match self {
-      Query::Movies => write!(f, "movie"),
-      Query::Series => write!(f, "series"),
-    }
-  }
-}
-
+/// A special object (i.e. a handle) that is used to refer to a movie in the database.
 #[derive(Debug, Display, PartialEq, Eq, Hash, Clone, Copy, From, Into)]
 struct MoviesCookie(usize);
 
+/// A special object (i.e. a handle) that is used to refer to a series in the database.
 #[derive(Debug, Display, PartialEq, Eq, Hash, Clone, Copy, From, Into)]
 struct SeriesCookie(usize);
 
-/// Provides an interface for the movies and series databases
+/// The primary API for access the movies and series database.
 pub struct Db {
   movies: DbImpl<MoviesCookie>,
   series: DbImpl<SeriesCookie>,
 }
 
 impl Db {
-  /// Initializes a movies and series database with the given capacity
+  /// Construct a database for movies and series, with a starting capacity for each.
+  ///
   /// # Arguments
-  /// * `movies_capacity` - Capacity of the movies database
-  /// * `series_capacity` - Capacity of the series database
-  pub fn with_capacities(movies_capacity: usize, series_capacity: usize) -> Self {
-    Self { movies: DbImpl::with_capacity(movies_capacity), series: DbImpl::with_capacity(series_capacity) }
+  ///
+  /// * `movies_cap` - Starting capacity of the movies database.
+  /// * `series_cap` - Starting capacity of the series database.
+  pub fn with_capacities(movies_cap: usize, series_cap: usize) -> Self {
+    let movies = DbImpl::with_capacity(movies_cap);
+    let series = DbImpl::with_capacity(series_cap);
+    Self { movies, series }
   }
 
-  /// Returns the number of titles in the movies database
+  /// The number of titles in the movies database.
   pub fn n_movies(&self) -> usize {
     self.movies.n_titles()
   }
 
-  /// Returns the number of titles in the series database
+  /// The number of titles in the series database.
   pub fn n_series(&self) -> usize {
     self.series.n_titles()
   }
 
-  /// Returns the total number of titles in movies and series databases
+  /// The total number of titles in the database.
   pub fn n_entries(&self) -> usize {
     self.n_movies() + self.n_series()
   }
 
-  /// Inserts the given title into the movies database
+  /// Insert a given title into the movies database.
+  ///
   /// # Arguments
-  /// * `title` - Title to be inserted into the movies database
+  ///
+  /// * `title` - The title to be inserted.
   pub(crate) fn store_movie(&mut self, title: Title<'static>) {
     self.movies.store_title(title)
   }
 
-  /// Inserts the given title into the series database
+  /// Insert the given title into the series database.
+  ///
   /// # Arguments
-  /// * `title` - Title to be inserted into the series database
+  ///
+  /// * `title` - The title to be inserted.
   pub(crate) fn store_series(&mut self, title: Title<'static>) {
     self.series.store_title(title)
   }
 
-  /// Reads movies/series data from tab separated values and writes as binary
+  /// Convert title data from tab separated values (TSVs) to binary.
+  ///
   /// # Arguments
-  /// * `ratings_reader` - Tab separated values for ratings
-  /// * `basics_reader` - Tab separated values for titles
-  /// * `movies_db_writer` - Writer to store movies
-  /// * `series_db_writer` - Writer to store series
+  ///
+  /// * `ratings_reader` - TSV reader for ratings.
+  /// * `basics_reader` - TSV reader for title data.
+  /// * `movies_db_writer` - Binary writer to store movies.
+  /// * `series_db_writer` - Binary writer to store series.
   pub(crate) fn to_binary<R1: BufRead, R2: BufRead, W1: Write, W2: Write>(
     ratings_reader: R1,
     mut basics_reader: R2,
@@ -131,10 +137,12 @@ impl Db {
     Ok(())
   }
 
-  /// Returns the title with the given ID from the database
+  /// Return the title with the given ID from the database.
+  ///
   /// # Arguments
-  /// * `TitleId` - Title ID to be queried
-  /// * `query` - Specifies if the query is for movies or series
+  ///
+  /// * `id` - Title ID to lookup.
+  /// * `query` - Whether to query movies or series.
   pub(crate) fn by_id(&self, id: &TitleId, query: Query) -> Option<&Title> {
     match query {
       Query::Movies => self.movies.by_id(id),
@@ -142,10 +150,12 @@ impl Db {
     }
   }
 
-  /// Returns titles with the given title string from the database
+  /// Search for titles by name.
+  ///
   /// # Arguments
-  /// * `title` - Title to be queried
-  /// * `query` - Specifies if the query is for movies or series
+  ///
+  /// * `title` - The title name to search for.
+  /// * `query` - Whether to query movies or series.
   pub(crate) fn by_title<'a>(
     &'a self,
     title: &str,
@@ -157,11 +167,13 @@ impl Db {
     }
   }
 
-  /// Returns titles by title and year from the database
+  /// Search for titles by name and year.
+  ///
   /// # Arguments
-  /// * `title` - Title to be queried
-  /// * `year` - Release date to be queried
-  /// * `query` - Specifies if the query is for movies or series
+  ///
+  /// * `title` - The title name to search for.
+  /// * `year` - The year to search for titles in.
+  /// * `query` - Whether to query movies or series.
   pub(crate) fn by_title_and_year<'a>(
     &'a self,
     title: &str,
@@ -174,10 +186,12 @@ impl Db {
     }
   }
 
-  /// Returns titles by keywords
+  /// Search for titles by keywords.
+  ///
   /// # Arguments
-  /// * `keywords` - Keywords to be searched in the titles
-  /// * `query` - Specifies if the query is for movies or series
+  ///
+  /// * `keywords` - Keywords to search for in title names.
+  /// * `query` - Whether to query movies or series.
   pub(crate) fn by_keywords<'a, 'k>(
     &'a self,
     keywords: &'k [&str],
@@ -189,11 +203,13 @@ impl Db {
     }
   }
 
-  /// Returns titles by keywords and year from the database
+  /// Search for titles by keywords and year.
+  ///
   /// # Arguments
-  /// * `keywords` - Keywords to be searched in the titles
-  /// * `year` - Release date to be queried
-  /// * `query` - Specifies if the query is for movies or series
+  ///
+  /// * `keywords` - Keywords to search for in title names.
+  /// * `year` - The year to search for titles in.
+  /// * `query` - Whether to query movies or series.
   pub(crate) fn by_keywords_and_year<'a, 'k>(
     &'a self,
     keywords: &'k [&str],
@@ -212,9 +228,9 @@ type ByYear<C> = FnvHashMap<u16, Vec<C>>;
 type ByTitle<C> = HashMap<String, ByYear<C>>;
 
 struct DbImpl<C> {
-  /// Titles information.
+  /// The actual storage of title information.
   titles: Vec<Title<'static>>,
-  /// Map from title ID to Title.
+  /// Map from title IDs to Titles.
   by_id: ById<C>,
   /// Map from years to title names to Titles.
   by_title: ByTitle<C>,
@@ -235,9 +251,11 @@ impl<C: From<usize>> DbImpl<C> {
 }
 
 impl<C: From<usize> + Into<usize> + Copy> DbImpl<C> {
-  /// Inserts the given title into the database
+  /// Insert a given title into the database.
+  ///
   /// # Arguments
-  /// * `title` - Title to be inserted into the database
+  ///
+  /// * `title` - The title to be inserted.
   fn store_title(&mut self, title: Title<'static>) {
     let cookie = self.next_cookie();
 
@@ -268,36 +286,47 @@ impl<C: From<usize> + Into<usize> + Copy> DbImpl<C> {
 }
 
 impl<C> DbImpl<C> {
-  /// Initializes and returns a database with the given capacity
+  /// Construct a database with a starting capacity.
+  ///
   /// # Arguments
-  /// * `capacity` - Maximum number of titles to be hold in the database
-  fn with_capacity(capacity: usize) -> Self {
-    Self { titles: Vec::with_capacity(capacity), by_id: Default::default(), by_title: Default::default() }
+  ///
+  /// * `cap` - Starting capacity of the database.
+  fn with_capacity(cap: usize) -> Self {
+    let titles = Vec::with_capacity(cap);
+    let by_id = Default::default();
+    let by_title = Default::default();
+    Self { titles, by_id, by_title }
   }
 
-  /// Inserts the given title into the database
+  /// Insert a title into the database.
+  ///
   /// # Arguments
-  /// * `title` - Title to be stored in the database
+  ///
+  /// * `title` - The title to be stored.
   fn store(&mut self, title: Title<'static>) {
     self.titles.push(title);
   }
 
-  /// Returns the number of titles in the database
+  /// The number of titles stored in the database.
   fn n_titles(&self) -> usize {
     self.titles.len()
   }
 
-  /// Returns the cookie with the given title ID
+  /// Return a cookie for the given title ID.
+  ///
   /// # Arguments
-  /// * `id` - Title ID to be queried
+  ///
+  /// * `id` - Title ID to search for.
   fn cookie_by_id(&self, id: &TitleId) -> Option<&C> {
     self.by_id.get(&id.as_usize())
   }
 
-  /// Returns cookies with the given title and year
+  /// Search for titles with the given title and year.
+  ///
   /// # Arguments
-  /// * `title` - Title to be queried
-  /// * `year` - Release date to be queried
+  ///
+  /// * `title` - The title name to search for.
+  /// * `year` - The year to search for titles in.
   fn cookies_by_title_and_year(&self, title: &str, year: u16) -> impl Iterator<Item = &C> {
     if let Some(by_year) = self.by_title.get(title) {
       if let Some(cookies) = by_year.get(&year) {
@@ -308,9 +337,11 @@ impl<C> DbImpl<C> {
     [].iter()
   }
 
-  /// Returns cookies by keywords
+  /// Search for titles by keywords.
+  ///
   /// # Arguments
-  /// * `keywords` - Keywords to be searched in the titles
+  ///
+  /// * `keywords` - Keywords to search for in title names.
   fn cookies_by_keywords<'a, 'k>(&'a self, keywords: &'k [&str]) -> impl Iterator<Item = &'a C> {
     let searcher = AhoCorasickBuilder::new().match_kind(ACMatchKind::LeftmostFirst).build(keywords);
     let keywords_len = keywords.len();
@@ -325,10 +356,12 @@ impl<C> DbImpl<C> {
       .flatten()
   }
 
-  /// Returns cookies by keywords and year
+  /// Search for titles by keywords and year.
+  ///
   /// # Arguments
-  /// * `keywords` - Keywords to be searched in the titles
-  /// * `year` - Release date to be queried
+  ///
+  /// * `keywords` - Keywords to search for in title names.
+  /// * `year` - The year to search for titles in.
   fn cookies_by_keywords_and_year<'a, 'k>(
     &'a self,
     keywords: &'k [&str],
@@ -347,19 +380,23 @@ impl<C> DbImpl<C> {
       .flatten()
   }
 
-  /// Inserts cookie with the given title ID
+  /// Insert a cookie with the given title ID.
+  ///
   /// # Arguments
-  /// * `id` - Title ID of the cookie
-  /// * `cookie` - Cookie to be inserted
+  ///
+  /// * `id` - Title ID to insert the cookie for.
+  /// * `cookie` - Cookie to be inserted.
   fn insert_by_id(&mut self, id: &TitleId, cookie: C) -> bool {
     self.by_id.insert(id.as_usize(), cookie).is_none()
   }
 
-  /// Inserts cookie with the given title and year
+  /// Insert cookie for the title with the given name and year.
+  ///
   /// # Arguments
-  /// * `title` - Title of the cookie to be inserted
-  /// * `year` - Release date of the cookie to be inserted
-  /// * `cookie` - Cookie to be inserted
+  ///
+  /// * `title` - Name of the title to be inserted.
+  /// * `year` - Release year of the title to be inserted.
+  /// * `cookie` - Cookie to be inserted.
   fn insert_by_title_and_year(&mut self, title: String, year: Option<u16>, cookie: C) {
     if let Some(year) = year {
       self.by_title.entry(title).or_default().entry(year).or_default().push(cookie);
@@ -370,16 +407,20 @@ impl<C> DbImpl<C> {
 }
 
 impl<C: Into<usize> + Copy> DbImpl<C> {
-  /// Returns the title with the given ID from the database
+  /// Find title by IMDB ID.
+  ///
   /// # Arguments
-  /// * `id` - ID of the title to be returned
+  ///
+  /// * `id` - Title ID to find.
   pub(crate) fn by_id(&self, id: &TitleId) -> Option<&Title> {
     self.cookie_by_id(id).map(|&cookie| &self[cookie])
   }
 
-  /// Returns titles with the given title string from the database
+  /// Find titles by name.
+  ///
   /// # Arguments
-  /// * `title` - Title to be queried
+  ///
+  /// * `title` - Title name to search for.
   pub(crate) fn by_title<'a>(&'a self, title: &str) -> Box<dyn Iterator<Item = &Title> + 'a> {
     if let Some(by_year) = self.by_title.get(title) {
       return Box::new(by_year.values().flatten().map(|&cookie| &self[cookie]));
@@ -388,25 +429,31 @@ impl<C: Into<usize> + Copy> DbImpl<C> {
     Box::new(std::iter::empty())
   }
 
-  /// Returns titles by title and year from the database
+  /// Find titles by name and year.
+  ///
   /// # Arguments
-  /// * `title` - Title to be queried
-  /// * `year` - Release date of the title to be queried
+  ///
+  /// * `title` - Title name to search for.
+  /// * `year` - The year to search for titles in.
   pub(crate) fn by_title_and_year(&self, title: &str, year: u16) -> impl Iterator<Item = &Title> {
     self.cookies_by_title_and_year(title, year).map(|&cookie| &self[cookie])
   }
 
-  /// Returns titles by keywords from the database
+  /// Search for titles by keywords.
+  ///
   /// # Arguments
-  /// * `keywords` - Keywords to be searched in the titles
+  ///
+  /// * `keywords` - Keywords to search for.
   pub(crate) fn by_keywords<'a, 'k>(&'a self, keywords: &'k [&str]) -> impl Iterator<Item = &'a Title> {
     self.cookies_by_keywords(keywords).map(|&cookie| &self[cookie])
   }
 
-  /// Returns titles by keywords and year from the database
+  /// Search for titles by keywords and year.
+  ///
   /// # Arguments
-  /// * `keywords` - Keywords to be searched in the titles
-  /// * `year` - Release date of the title to be queried
+  ///
+  /// * `keywords` - Keywords to search for.
+  /// * `year` - The year to search for titles in.
   pub(crate) fn by_keywords_and_year<'a, 'k>(
     &'a self,
     keywords: &'k [&str],
