@@ -2,29 +2,26 @@
 
 use crate::imdb::error::Err;
 use crate::imdb::utils::tokens;
-use atoi::atoi;
+use atoi::FromRadix10;
 use serde::{Serialize, Serializer};
 use std::error::Error;
 use std::fmt;
 use std::hash::{Hash, Hasher};
 
 /// The ID corresponding to a title as u8 and usize
-#[derive(Debug, Clone, Copy, Serialize)]
+#[derive(Debug, Clone, Copy)]
 pub struct TitleId<'storage> {
-  #[serde(serialize_with = "bytes_serializer", rename = "title_id")]
   bytes: &'storage [u8],
-
-  #[serde(skip_serializing)]
   num: usize,
 }
 
-fn bytes_serializer<S>(bytes: &[u8], serializer: S) -> Result<S::Ok, S::Error>
-where
-  S: Serializer,
-{
-  let s = unsafe { std::str::from_utf8_unchecked(bytes) };
-
-  serializer.serialize_str(s)
+impl<'storage> Serialize for TitleId<'storage> {
+  fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
+  where
+    S: Serializer,
+  {
+    serializer.serialize_str(unsafe { std::str::from_utf8_unchecked(self.bytes) })
+  }
 }
 
 impl PartialEq for TitleId<'_> {
@@ -66,8 +63,12 @@ impl<'storage> TryFrom<&'storage [u8]> for TitleId<'storage> {
       return Err::id(unsafe { std::str::from_utf8_unchecked(bytes) }.to_owned());
     }
 
-    let num = atoi::<usize>(&bytes[2..])
-      .ok_or_else(|| Err::IdNumber(unsafe { std::str::from_utf8_unchecked(bytes) }.to_owned()))?;
+    let num = &bytes[2..];
+    let num_len = num.len();
+    let num = match usize::from_radix_10(num) {
+      (val, len) if len == num_len => val,
+      _ => return Err::id_number(unsafe { std::str::from_utf8_unchecked(bytes) }.to_owned()),
+    };
 
     Ok(TitleId { bytes, num })
   }
