@@ -32,13 +32,13 @@ impl<'a> ImdbTitleInfo<'a> {
   }
 }
 
-fn deserialize_titleid<'de, D>(deserializer: D) -> Result<ImdbTitleId<'static>, D::Error>
+fn deserialize_titleid<'a, 'de, D>(deserializer: D) -> Result<ImdbTitleId<'a>, D::Error>
 where
   D: Deserializer<'de>,
 {
   let s = Box::leak(String::deserialize(deserializer)?.into_boxed_str());
-  let title_id = ImdbTitleId::try_from(s.as_bytes()).map_err(serde::de::Error::custom)?;
-  Ok(title_id)
+  let id = ImdbTitleId::try_from(s.as_bytes()).map_err(serde::de::Error::custom)?;
+  Ok(id)
 }
 
 #[derive(Serialize, Deserialize)]
