@@ -151,7 +151,7 @@ struct Opt {
 #[derive(Debug, clap::Subcommand)]
 enum Command {
   /// Lookup a single title using "KEYWORDS" or "TITLE (YYYY)"
-  Title {
+  Search {
     /// Search terms, as "KEYWORDS" or "TITLE (YYYY)"
     #[clap(name = "TITLE")]
     title: String,
@@ -168,7 +168,7 @@ enum Command {
   },
 
   /// Lookup movie titles from a directory
-  MoviesDir {
+  ScanMovies {
     /// Directory of movie folders named "TITLE (YYYY)"
     #[clap(name = "DIR")]
     dir: PathBuf,
@@ -181,7 +181,7 @@ enum Command {
   },
 
   /// Lookup series titles from a directory
-  SeriesDir {
+  ScanSeries {
     /// Directory of series folders named "TITLE [(YYYY)]"
     #[clap(name = "DIR")]
     dir: PathBuf,
@@ -636,7 +636,7 @@ fn main() {
   let args = Opt::parse();
 
   match args.command {
-    Command::Title { title, exact, general_opts, search_opts } => {
+    Command::Search { title, exact, general_opts, search_opts } => {
       let context = Context::new(general_opts, args.general_opts);
       let printer = create_output_printer(&search_opts.output, &context.general_opts);
       let start_time = Instant::now();
@@ -646,7 +646,7 @@ fn main() {
       debug!("IMDB query took {}", format_duration(Instant::now().duration_since(start_time)));
       context.destroy();
     }
-    Command::MoviesDir { dir, general_opts, search_opts } => {
+    Command::ScanMovies { dir, general_opts, search_opts } => {
       let context = Context::new(general_opts, args.general_opts);
       let printer = create_output_printer(&search_opts.output, &context.general_opts);
       let start_time = Instant::now();
@@ -656,7 +656,7 @@ fn main() {
       debug!("IMDB query took {}", format_duration(Instant::now().duration_since(start_time)));
       context.destroy();
     }
-    Command::SeriesDir { dir, general_opts, search_opts } => {
+    Command::ScanSeries { dir, general_opts, search_opts } => {
       let context = Context::new(general_opts, args.general_opts);
       let printer = create_output_printer(&search_opts.output, &context.general_opts);
       let start_time = Instant::now();
